package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.OrhonShzz;

/**
 * 社会组织信息Service接口
 *
 * @author ruoyi
 * @date 2020-07-20
 */
public interface IOrhonShzzService
{
    /**
     * 查询社会组织信息
     *
     * @param id 社会组织信息ID
     * @return 社会组织信息
     */
    public com.ruoyi.system.domain.OrhonShzz selectOrhonShzzById(String id);

    /**
     * 查询社会组织信息列表
     *
     * @param orhonShzz 社会组织信息
     * @return 社会组织信息集合
     */
    public java.util.List<com.ruoyi.system.domain.OrhonShzz> selectOrhonShzzList(com.ruoyi.system.domain.OrhonShzz orhonShzz);

    /**
     * 新增社会组织信息
     *
     * @param orhonShzz 社会组织信息
     * @return 结果
     */
    public int insertOrhonShzz(com.ruoyi.system.domain.OrhonShzz orhonShzz);

    /**
     * 修改社会组织信息
     *
     * @param orhonShzz 社会组织信息
     * @return 结果
     */
    public int updateOrhonShzz(com.ruoyi.system.domain.OrhonShzz orhonShzz);

    /**
     * 批量删除社会组织信息
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteOrhonShzzByIds(String ids);

    /**
     * 删除社会组织信息信息
     *
     * @param id 社会组织信息ID
     * @return 结果
     */
    public int deleteOrhonShzzById(String id);

    public String findQyzs();

    public String findShzz();
}
